# arpes.utilities.conversion.forward module

**arpes.utilities.conversion.forward.convert\_coordinates\_to\_kspace\_forward(arr:
xarray.core.dataarray.DataArray,**kwargs)\*\*

> Forward converts all the individual coordinates of the data array
> :param arr: :param kwargs: :return:
